Struct ferrilab::CurveFit

source ·
pub struct CurveFit<F: Fn(&f64, &[f64]) -> f64> { /* private fields */ }
Object to create a CurveFit with all required parameters.

Implementations

source

impl<F: Fn(&f64, &[f64]) -> f64> CurveFit<F>

source

pub fn new( model: F, x_values: impl Into<Vec<f64>>, y_values: impl Into<Vec<f64>> ) -> Self

Constructs a new CurveFit with some default values that can be changed.

source

pub fn initial_point(self, initial_point: impl Into<Vec<f64>>) -> Self

Initial points required for calculating the curve fit.

source

pub fn y_error(self, yerr: Vec<f64>) -> Self

If passed, calculates the weigthed curve fit considaring the y error.

source

pub fn max_iterations(self, max_iterations: impl Into<Option<usize>>) -> Self

In case you want the curve fit algorithm to stop at some point, by default None.

source

pub fn initial_zeros(self, number_of_components: usize) -> Self

Set initial points to zero.

source

pub fn initial_ones(self, number_of_components: usize) -> Self

Set initial points to one.

source

pub fn tolerance(self, tol: impl Into<f64>) -> Self

Custom precision on the curve fit, by default 1e-6.

source

pub fn initial_simplex_scale(self, scale: impl Into<f64>) -> Self

Generates n+1 points using the initial one for calculating the curve fit, by default 0.5. If the scale is a lot smaller than the expected value of the coeficients it may result in errors in the fit.

source

pub fn fit(&self) -> Vec<Measure>

Takes the arbitrary function and aproximates to the curve using every parameter established.

source

pub fn r_value(&self) -> f64